pipolars.PIConfig
=================

.. currentmodule:: pipolars

.. autoclass:: PIConfig

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~PIConfig.__init__
      ~PIConfig.construct
      ~PIConfig.copy
      ~PIConfig.dict
      ~PIConfig.from_file
      ~PIConfig.from_orm
      ~PIConfig.json
      ~PIConfig.model_construct
      ~PIConfig.model_copy
      ~PIConfig.model_dump
      ~PIConfig.model_dump_json
      ~PIConfig.model_json_schema
      ~PIConfig.model_parametrized_name
      ~PIConfig.model_post_init
      ~PIConfig.model_rebuild
      ~PIConfig.model_validate
      ~PIConfig.model_validate_json
      ~PIConfig.model_validate_strings
      ~PIConfig.parse_file
      ~PIConfig.parse_obj
      ~PIConfig.parse_raw
      ~PIConfig.schema
      ~PIConfig.schema_json
      ~PIConfig.settings_customise_sources
      ~PIConfig.to_dict
      ~PIConfig.update_forward_refs
      ~PIConfig.validate
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~PIConfig.model_computed_fields
      ~PIConfig.model_config
      ~PIConfig.model_extra
      ~PIConfig.model_fields
      ~PIConfig.model_fields_set
      ~PIConfig.server
      ~PIConfig.af
      ~PIConfig.cache
      ~PIConfig.query
      ~PIConfig.polars
      ~PIConfig.debug
      ~PIConfig.log_level
   
   